/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.calcite.test;

import org.apache.calcite.util.Sources;

import java.net.URL;

import static java.util.Objects.requireNonNull;

/**
 * Common methods inheritable by all Pig-specific test classes.
 */
public abstract class AbstractPigTest {

  protected String getFullPathForTestDataFile(String fileName) {
    final URL url = getClass().getResource("/" + fileName);
    requireNonNull(url, "url");
    return Sources.of(url).file().getAbsolutePath();
  }
}
